Crate cs43l22_embedded

Crate cs43l22_embedded 

Feature flags

No documented features in Cargo.toml

Structs

BeepConfig
Beep configuration This struct is used to configure the beep tone of the CS43L22 It contains the pitch, on time, off time, mode, mix and volume
Config
CS43L22 configuration This struct is used to configure the CS43L22 driver It contains the output device, interface format, word length and volume
Cs43l22
CS43L22 driver This struct represents a CS43L22 driver It contains an I2C interface and a configuration It is used to control the CS43L22 The driver is generic over the I2C interface The I2C interface must implement the embedded_hal::i2c::I2c trait The I2C error type must implement the core::fmt::Debug trait

Enums

BassCutoff
Bass cutoff frequency This is used to set the bass cutoff frequency of the CS43L22
BeepMode
Beep mode
BeepOffTime
Time the beep is off
BeepOnTime
Time the beep is on
BeepPitch
The output device of the CS43L22 This is used to select the output device of the CS43L22 on the register 0x04
Error
Errors that can occur when using the CS43L22 driver
InterfaceFormat
Interface format of the I2S stream
OutputDevice
The output device of the CS43L22 This is used to select the output device of the CS43L22 on the register 0x04
PCMmix
PCM mix This is used to set the PCM mix of the CS43L22 In summary, it is used to set the gain of the left and right channels of the I2S stream
ToneGain
Tone gain This is used to set the treble and bass gain of the CS43L22
TrebleCutoff
Treble cutoff frequency This is used to set the treble cutoff frequency of the CS43L22
WordLength
Word length of the I2S stream

Type Aliases

Result
Type alias for the result of a CS43L22 operation