BeepConfig

Struct BeepConfig 

pub struct BeepConfig { /* private fields */ }
Beep configuration This struct is used to configure the beep tone of the CS43L22 It contains the pitch, on time, off time, mode, mix and volume

Implementations

Source

impl BeepConfig

pub fn new() -> Self

Create a new CS43L22 configuration

pub fn pitch(self, pitch: BeepPitch) -> Self

Set the pitch

pub fn on_time(self, on_time: BeepOnTime) -> Self

Set the on time

pub fn off_time(self, off_time: BeepOffTime) -> Self

Set the off time

pub fn volume(self, volume: u16) -> Self

Set the volume

pub fn mode(self, mode: BeepMode) -> Self

Set the mode

pub fn mix(self, mix: bool) -> Self

Set the mix