Config

Struct Config 

pub struct Config { /* private fields */ }
CS43L22 configuration This struct is used to configure the CS43L22 driver It contains the output device, interface format, word length and volume

Implementations

Source

impl Config

pub fn new() -> Self

Create a new CS43L22 configuration

pub fn output_device(self, output_device: OutputDevice) -> Self

Set the output device

pub fn interface_format(self, interface_format: InterfaceFormat) -> Self

Set the interface format

pub fn word_length(self, word_length: WordLength) -> Self

Set the word length

pub fn volume_a(self, volume: u16) -> Self

Set the volume

pub fn volume_b(self, volume: u16) -> Self

Set the volume

pub fn treble_cutoff(self, treble_cutoff: TrebleCutoff) -> Self

Set the treble cutoff frequency

pub fn treble_gain(self, treble_gain: ToneGain) -> Self

Set the treble gain

pub fn bass_cutoff(self, bass_cutoff: BassCutoff) -> Self

Set the bass cutoff frequency

pub fn bass_gain(self, bass_gain: ToneGain) -> Self

Set the bass gain

pub fn with_tone_control(self, tone_control: bool) -> Self

Set the tone control