Feature flags
No documented features in Cargo.toml
Structs
- Beep
Config - Beep configuration This struct is used to configure the beep tone of the CS43L22 It contains the pitch, on time, off time, mode, mix and volume
- Config
- CS43L22 configuration This struct is used to configure the CS43L22 driver It contains the output device, interface format, word length and volume
- Cs43l22
- CS43L22 driver
This struct represents a CS43L22 driver
It contains an I2C interface and a configuration
It is used to control the CS43L22
The driver is generic over the I2C interface
The I2C interface must implement the
embedded_hal::i2c::I2ctrait The I2C error type must implement thecore::fmt::Debugtrait
Enums
- Bass
Cutoff - Bass cutoff frequency This is used to set the bass cutoff frequency of the CS43L22
- Beep
Mode - Beep mode
- Beep
OffTime - Time the beep is off
- Beep
OnTime - Time the beep is on
- Beep
Pitch - The output device of the CS43L22 This is used to select the output device of the CS43L22 on the register 0x04
- Error
- Errors that can occur when using the CS43L22 driver
- Interface
Format - Interface format of the I2S stream
- Output
Device - The output device of the CS43L22 This is used to select the output device of the CS43L22 on the register 0x04
- PCMmix
- PCM mix This is used to set the PCM mix of the CS43L22 In summary, it is used to set the gain of the left and right channels of the I2S stream
- Tone
Gain - Tone gain This is used to set the treble and bass gain of the CS43L22
- Treble
Cutoff - Treble cutoff frequency This is used to set the treble cutoff frequency of the CS43L22
- Word
Length - Word length of the I2S stream
Type Aliases
- Result
- Type alias for the result of a CS43L22 operation