pub enum PCMmix {
Left,
Half,
Right,
}Expand description
PCM mix This is used to set the PCM mix of the CS43L22 In summary, it is used to set the gain of the left and right channels of the I2S stream
Variants