pub struct BeepConfig { /* private fields */ }Expand description
Beep configuration This struct is used to configure the beep tone of the CS43L22 It contains the pitch, on time, off time, mode, mix and volume
Implementations
Sourceimpl BeepConfig
impl BeepConfig
Sourcepub fn on_time(self, on_time: BeepOnTime) -> Self
pub fn on_time(self, on_time: BeepOnTime) -> Self
Set the on time
Sourcepub fn off_time(self, off_time: BeepOffTime) -> Self
pub fn off_time(self, off_time: BeepOffTime) -> Self
Set the off time