pub struct Config { /* private fields */ }Expand description
CS43L22 configuration This struct is used to configure the CS43L22 driver It contains the output device, interface format, word length and volume
Implementations
Sourceimpl Config
impl Config
Sourcepub fn output_device(self, output_device: OutputDevice) -> Self
pub fn output_device(self, output_device: OutputDevice) -> Self
Set the output device
Sourcepub fn interface_format(self, interface_format: InterfaceFormat) -> Self
pub fn interface_format(self, interface_format: InterfaceFormat) -> Self
Set the interface format
Sourcepub fn word_length(self, word_length: WordLength) -> Self
pub fn word_length(self, word_length: WordLength) -> Self
Set the word length
Sourcepub fn treble_cutoff(self, treble_cutoff: TrebleCutoff) -> Self
pub fn treble_cutoff(self, treble_cutoff: TrebleCutoff) -> Self
Set the treble cutoff frequency
Sourcepub fn treble_gain(self, treble_gain: ToneGain) -> Self
pub fn treble_gain(self, treble_gain: ToneGain) -> Self
Set the treble gain
Sourcepub fn bass_cutoff(self, bass_cutoff: BassCutoff) -> Self
pub fn bass_cutoff(self, bass_cutoff: BassCutoff) -> Self
Set the bass cutoff frequency
Sourcepub fn with_tone_control(self, tone_control: bool) -> Self
pub fn with_tone_control(self, tone_control: bool) -> Self
Set the tone control